"""
@File    :   utils.py
@Time    :   2024/09/26 10:40:58
@Author  :   TankNee
@Version :   1.0
@Desc    :   Utils
"""


import re


def markdown_table_to_json(markdown_table: str):
    """Convert a Markdown table to a list of dictionaries.

    Args:
        markdown_table (str): A Markdown table.

    Returns:
        list: A list of dictionaries.
    """
    lines = markdown_table.split("\n")
    headers = [
        header.strip() for header in re.split(r"\s*\|\s*", lines[0]) if header.strip()
    ]
    data_lines = [line for line in lines[2:] if line.strip()]
    json_list = []
    for line in data_lines:
        values = [
            value.strip() for value in re.split(r"\s*\|\s*", line) if value.strip()
        ]
        item = {}
        for i, header in enumerate(headers):
            item[header] = values[i]
        json_list.append(item)
    return json_list


def json_to_markdown_table(json_list: list):
    """Convert a list of dictionaries to a Markdown table.
    
    Args:
        json_list (list): A list of dictionaries.
    
    Returns:
        str: A Markdown table.
    """
    if not json_list:
        return ""
    # 获取表头（第一个字典的键）
    headers = list(json_list[0].keys())
    # 创建 Markdown 表格的表头行
    markdown_table = "| " + " | ".join(headers) + " |\n"
    markdown_table += "| " + " | ".join(["---"] * len(headers)) + " |\n"
    # 添加数据行
    for item in json_list:
        values = [str(item[key]) for key in headers]
        markdown_table += "| " + " | ".join(values) + " |\n"
    return markdown_table



import os

from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), "README.md"), "r", encoding="utf-8") as f:
    long_description = f.read()

setup(name="neetils",
      version="v1.0.3",
      author="tanknee",
      author_email="nee@tanknee.cn",
      description="A package for tools",
      long_description=long_description,
      long_description_content_type="text/markdown",
      packages=find_packages(include=["neetils", "neetils.*", "README.md"]),
      install_requires=[
          "tqdm",
          "loguru",
      ])


"""
@File    :   io.py
@Time    :   2024/04/25 09:55:59
@Author  :   TankNee
@Version :   1.0
@Desc    :   IO Tools
"""

import json
from typing import Union
from tqdm import tqdm
import yaml


def read_jsonl(file_path: str):
    """Read a JSONL file and return a list of dictionaries.

    Args:
        file_path (str): The path to the JSONL file.

    Returns:
        list: A list of dictionaries.
    """
    with open(file_path, "r") as f:
        basename = file_path.split("/")[-1]
        data = f.readlines()
        results = []
        for line in tqdm(data, desc=basename, leave=False):
            results.append(json.loads(line))
    return results


def write_jsonl(file_path: str, data: list):
    """Write a list of dictionaries to a JSONL file.

    Args:
        file_path (str): The path to the JSONL file.
        data (list): A list of dictionaries.
    """
    with open(file_path, "w", encoding="utf-8") as f:
        for line in data:
            f.write(json.dumps(line, ensure_ascii=False) + "\n")


def read_yaml(file_path: str):
    """Read a YAML file and return a dictionary.

    Args:
        file_path (str): The path to the YAML file.

    Returns:
        dict: A dictionary.
    """
    with open(file_path, "r", encoding="utf-8") as f:
        return yaml.load(f, Loader=yaml.FullLoader)


def write_yaml(file_path: str, data: dict):
    """Write a dictionary to a YAML file.

    Args:
        file_path (str): The path to the YAML file.
        data (dict): A dictionary

    Returns:
        None
    """
    with open(file_path, "w", encoding="utf-8") as f:
        yaml.dump(data, f, allow_unicode=True)


def read_json(file_path):
    """Read a JSON file and return a dictionary.

    Args:
        file_path (str): The path to the JSON file.

    Returns:
        dict: A dictionary.
    """
    with open(file_path, "r", encoding="utf-8") as f:
        return json.load(f)


def write_json(file_path: str, data: Union[dict | list]):
    """Write a dictionary to a JSON file.

    Args:
        file_path (str): The path to the JSON file.
        data (dict): A dictionary.

    Returns:
        None
    """
    with open(file_path, "w", encoding="utf-8") as f:
        json.dump(data, f, ensure_ascii=False, indent=4)
